@@ -50,6 +50,7 @@
 #define PSF_E_BANNED    (-10)	/* Invalid Unicode code point */
 #define PSF_E_PARSE     (-11)   /* Invalid Unicode sequence string */
 #define PSF_E_RANGE	(-12)	/* Character index out of range */
+#define PSF_E_NOTVFONT  (-13)    /* Attempt to load a non-VFONT */
 
 typedef unsigned char  psf_byte;
 typedef unsigned short psf_word;
@@ -281,6 +282,11 @@ psf_errno_t vfont_unicode_delete(VFONT *f, psf_word nchar, psf_dword token);
 /* Find a token in the Unicode directory */
 psf_errno_t vfont_unicode_lookup(VFONT *f, psf_dword token, psf_dword *nchar);
 psf_errno_t vfont_unicode_from_string(VFONT *f, psf_word nchar, const char *str);
+/* Add a chain to the Unicode directory from the map */
+psf_errno_t vfont_unicode_addmap(VFONT *f, psf_word destchar,
+	                                PSF_MAPPING *m, psf_word slot);
+/* Find a token in the Unicode directory, based on chain slot in mapping m */
+psf_errno_t vfont_unicode_lookupmap(VFONT *f, PSF_MAPPING *m, psf_word slot, psf_dword *nchar, psf_dword *found);
 
 psf_errno_t vfont_force_v1(VFONT *f);
 psf_errno_t vfont_force_v2(VFONT *f);
@@ -292,14 +298,19 @@ psf_errno_t vfont_mem_write (VFONT *f, psf_byte *data, unsigned len);
 
 psf_errno_t vfont_get_pixel(VFONT *f, psf_dword ch, psf_dword x, psf_dword y, psf_byte *pixel);
 psf_errno_t vfont_set_pixel(VFONT *f, psf_dword ch, psf_dword x, psf_dword y, psf_byte pixel);
-/* Get dimensions of a character bitmap */
+/* Get the actual width and height of a character bitmap */
 psf_errno_t vfont_get_charsize(VFONT *f, psf_dword ch, psf_dword *x, psf_dword *y);
-/* Get dimensions of a character cell */
+/* Get dimensions of a character cell. This is the bitmap size, plus any 
+ * extra columns / rows necessary to include the origin point */
 psf_errno_t vfont_get_cellsize(VFONT *f, psf_dword ch, psf_dword *x, psf_dword *y);
 
-/* Get max dimensions of a character bitmap */
+/* Get the dimensions of the biggest bitmap needed to hold any character 
+ * in the font */
 psf_errno_t vfont_get_max_charsize(VFONT *f, psf_dword *x, psf_dword *y);
-/* Get max dimensions of a character cell */
+/* Get the dimensions of the biggest cell needed to hold any character 
+ * in the font and its origin point. 
+ * base_x and base_y will be set to the location of the origin point in 
+ * this cell. */
 psf_errno_t vfont_get_max_cellsize(VFONT *f, 
 		psf_dword *cell_w, psf_dword *cell_h,
 		psf_dword *base_x, psf_dword *base_y);
